antares.apps.document.views package
===================================

Submodules
----------

antares.apps.document.views.document\_create\_view module
---------------------------------------------------------

.. automodule:: antares.apps.document.views.document_create_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.document.views.document\_edit\_view module
-------------------------------------------------------

.. automodule:: antares.apps.document.views.document_edit_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.document.views.document\_view\_view module
-------------------------------------------------------

.. automodule:: antares.apps.document.views.document_view_view
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.document.views
   :members:
   :undoc-members:
   :show-inheritance:
